@@ -69,14 +69,14 @@ public:
     explicit AgendaHeaderLayout(QWidget *parent);
     ~AgendaHeaderLayout() override;
 
-public: // QLayout API
+    // QLayout API
     int count() const override;
     QLayoutItem *itemAt(int index) const override;
 
     void addItem(QLayoutItem *item) override;
     QLayoutItem *takeAt(int index) override;
 
-public: // QLayoutItem API
+    // QLayoutItem API
     QSize sizeHint() const override;
     QSize minimumSize() const override;
 
@@ -86,7 +86,6 @@ public: // QLayoutItem API
 private:
     void updateCache() const;
 
-private:
     QList<QLayoutItem *> mItems;
 
     mutable bool mIsDirty = false;
@@ -208,10 +207,9 @@ public:
 
     using DecorationList = QList<EventViews::CalendarDecoration::Decoration *>;
 
-public:
     void setCalendarName(const QString &calendarName);
     void setAgenda(Agenda *agenda);
-    bool createDayLabels(const KCalendarCore::DateList &dates, bool withDayLabel, const QStringList &decos, const QStringList &enabledDecos);
+    bool createDayLabels(const KCalendarCore::DateList &dates, bool withDayLabel, const QStringList &decoNames, const QStringList &enabledDecos);
     void setWeekWidth(int width);
     void updateDayLabelSizes();
     void updateMargins();
@@ -227,7 +225,6 @@ private:
     void placeDecorations(const DecorationList &decoList, QDate date, QWidget *labelBox, bool forWeek);
     void loadDecorations(const QStringList &decorations, const QStringList &whiteList, DecorationList &decoList);
 
-private:
     const bool mIsSideBySide;
 
     Agenda *mAgenda = nullptr;
@@ -304,7 +301,7 @@ void AgendaHeader::updateDayLabelSizes()
     // First, calculate the maximum text type that fits for all labels
     AlternateLabel::TextType overallType = AlternateLabel::Extensive;
     for (auto label : std::as_const(mDateDayLabels)) {
-        AlternateLabel::TextType type = label->largestFittingTextType();
+        AlternateLabel::TextType const type = label->largestFittingTextType();
         if (type < overallType) {
             overallType = type;
         }
@@ -342,12 +339,12 @@ void AgendaHeader::clear()
     mDateDayLabels.clear();
 }
 
-bool AgendaHeader::createDayLabels(const KCalendarCore::DateList &dates, bool withDayLabel, const QStringList &decoNames, const QStringList &enabledPlugins)
+bool AgendaHeader::createDayLabels(const KCalendarCore::DateList &dates, bool withDayLabel, const QStringList &decoNames, const QStringList &enabledDecos)
 {
     clear();
 
     QList<CalendarDecoration::Decoration *> decos;
-    loadDecorations(decoNames, enabledPlugins, decos);
+    loadDecorations(decoNames, enabledDecos, decos);
     const bool hasDecos = !decos.isEmpty();
 
     for (const QDate &date : dates) {
@@ -377,13 +374,13 @@ void AgendaHeader::addDay(const DecorationList &decoList, QDate date, bool withD
     mDayLabelsLayout->addWidget(topDayLabelBox);
 
     if (withDayLabel) {
-        int dW = date.dayOfWeek();
-        QString veryLongStr = QLocale::system().toString(date, QLocale::LongFormat);
-        QString longstr = i18nc("short_weekday short_monthname date (e.g. Mon Aug 13)",
-                                "%1 %2 %3",
-                                QLocale::system().dayName(dW, QLocale::ShortFormat),
-                                QLocale::system().monthName(date.month(), QLocale::ShortFormat),
-                                date.day());
+        int const dW = date.dayOfWeek();
+        QString const veryLongStr = QLocale::system().toString(date, QLocale::LongFormat);
+        QString const longstr = i18nc("short_weekday short_monthname date (e.g. Mon Aug 13)",
+                                      "%1 %2 %3",
+                                      QLocale::system().dayName(dW, QLocale::ShortFormat),
+                                      QLocale::system().monthName(date.month(), QLocale::ShortFormat),
+                                      date.day());
         const QString shortstr = QString::number(date.day());
 
         auto dayLabel = new AlternateLabel(shortstr, longstr, veryLongStr, topDayLabelBox);
@@ -435,6 +432,7 @@ void AgendaHeader::loadDecorations(const QStringList &decorations, const QString
 {
     for (const QString &decoName : decorations) {
         if (whiteList.contains(decoName)) {
+            /* cppcheck-suppress constVariablePointer */
             CalendarDecoration::Decoration *deco = loadCalendarDecoration(decoName);
             if (deco != nullptr) {
                 decoList << deco;
@@ -469,8 +467,8 @@ public:
         ch = QChar(mLocation == EventIndicator::Top ? 0x21e1 : 0x21e3);
         QFont font = q->font();
         font.setPointSize(KIconLoader::global()->currentSize(KIconLoader::Dialog));
-        QFontMetrics fm(font);
-        QRect rect = fm.boundingRect(ch).adjusted(-2, -2, 2, 2);
+        QFontMetrics const fm(font);
+        QRect const rect = fm.boundingRect(ch).adjusted(-2, -2, 2, 2);
         mPixmap = QPixmap(rect.size());
         mPixmap.fill(Qt::transparent);
         QPainter p(&mPixmap);
@@ -490,7 +488,6 @@ public:
         q->setGeometry(rect);
     }
 
-public:
     int mColumns = 1;
     const EventIndicator::Location mLocation;
     QPixmap mPixmap;
@@ -568,7 +565,6 @@ public:
         mViewCalendar->mAgendaView = q;
     }
 
-public:
     // view widgets
     QVBoxLayout *mMainLayout = nullptr;
     AgendaHeader *mTopDayLabelsFrame = nullptr;
@@ -586,7 +582,6 @@ public:
 
     KCalendarCore::DateList mSelectedDates; // List of dates to be displayed
     KCalendarCore::DateList mSaveSelectedDates; // Save the list of dates between updateViews
-    int mViewType;
     EventIndicator *mEventIndicatorTop = nullptr;
     EventIndicator *mEventIndicatorBottom = nullptr;
 
@@ -687,13 +682,13 @@ bool AgendaViewPrivate::datesEqual(const KCalendarCore::Incidence::Ptr &one, con
 
 AgendaItem::List AgendaViewPrivate::agendaItems(const QString &uid) const
 {
-    AgendaItem::List allDayAgendaItems = mAllDayAgenda->agendaItems(uid);
-    return allDayAgendaItems.isEmpty() ? mAgenda->agendaItems(uid) : allDayAgendaItems;
+    AgendaItem::List const allDayAgendaItemList = mAllDayAgenda->agendaItems(uid);
+    return allDayAgendaItemList.isEmpty() ? mAgenda->agendaItems(uid) : allDayAgendaItemList;
 }
 
 bool AgendaViewPrivate::mightBeVisible(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    KCalendarCore::Todo::Ptr todo = incidence.dynamicCast<KCalendarCore::Todo>();
+    KCalendarCore::Todo::Ptr const todo = incidence.dynamicCast<KCalendarCore::Todo>();
 
     // KDateTime::toTimeSpec() is expensive, so lets first compare only the date,
     // to see if the incidence is visible.
@@ -810,20 +805,18 @@ void AgendaViewPrivate::calendarIncidenceChanged(const KCalendarCore::Incidence:
         return;
     }
 
-    AgendaItem::List agendaItems = this->agendaItems(incidence->uid());
-    if (agendaItems.isEmpty()) {
-        // Don't warn - it's possible the incidence has been changed in another calendar that we do not display.
-        // qCWarning(CALENDARVIEW_LOG) << "AgendaView::calendarIncidenceChanged() Invalid agendaItem for incidence " << incidence->uid();
+    AgendaItem::List agendaItemList = this->agendaItems(incidence->uid());
+    if (agendaItemList.isEmpty()) {
         return;
     }
 
     // Optimization: If the dates didn't change, just repaint it.
     // This optimization for now because we need to process collisions between agenda items.
-    if (false && !incidence->recurs() && agendaItems.count() == 1) {
-        KCalendarCore::Incidence::Ptr originalIncidence = agendaItems.first()->incidence();
+    if (false && !incidence->recurs() && agendaItemList.count() == 1) {
+        KCalendarCore::Incidence::Ptr const originalIncidence = agendaItemList.first()->incidence();
 
         if (datesEqual(originalIncidence, incidence)) {
-            for (const AgendaItem::QPtr &agendaItem : std::as_const(agendaItems)) {
+            for (const AgendaItem::QPtr &agendaItem : std::as_const(agendaItemList)) {
                 agendaItem->setIncidence(KCalendarCore::Incidence::Ptr(incidence->clone()));
                 agendaItem->update();
             }
@@ -835,7 +828,7 @@ void AgendaViewPrivate::calendarIncidenceChanged(const KCalendarCore::Incidence:
         // Reevaluate the main event instead, if it exists
         const auto cal = q->calendar2(incidence);
         if (cal) {
-            KCalendarCore::Incidence::Ptr mainIncidence = cal->incidence(incidence->uid());
+            KCalendarCore::Incidence::Ptr const mainIncidence = cal->incidence(incidence->uid());
             reevaluateIncidence(mainIncidence ? mainIncidence : incidence);
         }
     } else {
@@ -863,7 +856,7 @@ void AgendaViewPrivate::calendarIncidenceDeleted(const KCalendarCore::Incidence:
         if (mViewCalendar->isValid(incidence->uid())) {
             const auto cal = q->calendar2(incidence->uid());
             if (cal) {
-                KCalendarCore::Incidence::Ptr mainIncidence = cal->incidence(incidence->uid());
+                KCalendarCore::Incidence::Ptr const mainIncidence = cal->incidence(incidence->uid());
                 if (mainIncidence) {
                     reevaluateIncidence(mainIncidence);
                 }
@@ -893,8 +886,8 @@ void EventViews::AgendaViewPrivate::setChanges(EventView::Changes changes, const
         mUpdateAllDayAgenda = true;
         mUpdateAgenda = true;
     } else if (incidence) {
-        mUpdateAllDayAgenda = mUpdateAllDayAgenda | incidence->allDay();
-        mUpdateAgenda = mUpdateAgenda | !incidence->allDay();
+        mUpdateAllDayAgenda = mUpdateAllDayAgenda || incidence->allDay();
+        mUpdateAgenda = mUpdateAgenda || !incidence->allDay();
     }
 
     q->EventView::setChanges(changes);
@@ -918,12 +911,14 @@ void AgendaViewPrivate::insertIncidence(const KCalendarCore::Incidence::Ptr &inc
                                         const QDateTime &insertAtDateTime,
                                         bool createSelected)
 {
+    /* cppcheck-suppress knownConditionTrueFalse */
+    /* we may want to make filterByCollectionSelection useful in the future */
     if (!q->filterByCollectionSelection(incidence)) {
         return;
     }
 
-    KCalendarCore::Event::Ptr event = CalendarSupport::event(incidence);
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(incidence);
+    KCalendarCore::Event::Ptr const event = CalendarSupport::event(incidence);
+    KCalendarCore::Todo::Ptr const todo = CalendarSupport::todo(incidence);
 
     const QDate insertAtDate = insertAtDateTime.date();
 
@@ -1256,7 +1251,7 @@ void AgendaView::removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar
 
     auto cal = std::find_if(d->mViewCalendar->mSubCalendars.cbegin(), d->mViewCalendar->mSubCalendars.cend(), [calendar](const auto &subcal) {
         if (auto akonadiCal = qSharedPointerDynamicCast<AkonadiViewCalendar>(subcal); akonadiCal) {
-            // TODO: FIXME: the pointer-based comparision MUST succeed here, not collection-based comparison!!!
+            // TODO: FIXME: the pointer-based comparison MUST succeed here, not collection-based comparison!!!
             return akonadiCal->mCalendar->collection() == calendar->collection();
         }
         return false;
@@ -1350,19 +1345,13 @@ void AgendaView::connectAgenda(Agenda *agenda, Agenda *otherAgenda)
     connect(agenda, &Agenda::incidenceSelected, this, &AgendaView::slotIncidenceSelected);
 
     // rescheduling of todos by d'n'd
-    connect(agenda,
-            qOverload<const KCalendarCore::Incidence::List &, const QPoint &, bool>(&Agenda::droppedIncidences),
-            this,
-            qOverload<const KCalendarCore::Incidence::List &, const QPoint &, bool>(&AgendaView::slotIncidencesDropped));
-    connect(agenda,
-            qOverload<const QList<QUrl> &, const QPoint &, bool>(&Agenda::droppedIncidences),
-            this,
-            qOverload<const QList<QUrl> &, const QPoint &, bool>(&AgendaView::slotIncidencesDropped));
+    connect(agenda, &Agenda::droppedIncidencesSignal, this, &AgendaView::slotIncidencesDropped);
+    connect(agenda, &Agenda::droppedUrlsSignal, this, &AgendaView::slotUrlsDropped);
 }
 
 void AgendaView::slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
-    Akonadi::Item item = d->mViewCalendar->item(incidence);
+    Akonadi::Item const item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
         Q_EMIT incidenceSelected(item, date);
     }
@@ -1370,7 +1359,7 @@ void AgendaView::slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &inci
 
 void AgendaView::slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
-    Akonadi::Item item = d->mViewCalendar->item(incidence);
+    Akonadi::Item const item = d->mViewCalendar->item(incidence);
     // qDebug() << "wanna see the popup for " << incidence->uid() << item.id();
     if (item.isValid()) {
         const auto calendar = calendar3(item);
@@ -1380,7 +1369,7 @@ void AgendaView::slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &inc
 
 void AgendaView::slotShowIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Akonadi::Item item = d->mViewCalendar->item(incidence);
+    Akonadi::Item const item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
         Q_EMIT showIncidenceSignal(item);
     }
@@ -1388,7 +1377,7 @@ void AgendaView::slotShowIncidence(const KCalendarCore::Incidence::Ptr &incidenc
 
 void AgendaView::slotEditIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Akonadi::Item item = d->mViewCalendar->item(incidence);
+    Akonadi::Item const item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
         Q_EMIT editIncidenceSignal(item);
     }
@@ -1396,7 +1385,7 @@ void AgendaView::slotEditIncidence(const KCalendarCore::Incidence::Ptr &incidenc
 
 void AgendaView::slotDeleteIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Akonadi::Item item = d->mViewCalendar->item(incidence);
+    Akonadi::Item const item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
         Q_EMIT deleteIncidenceSignal(item);
     }
@@ -1582,12 +1571,12 @@ Akonadi::Item::List AgendaView::selectedIncidences() const
 {
     Akonadi::Item::List selected;
 
-    KCalendarCore::Incidence::Ptr agendaitem = d->mAgenda->selectedIncidence();
+    KCalendarCore::Incidence::Ptr const agendaitem = d->mAgenda->selectedIncidence();
     if (agendaitem) {
         selected.append(d->mViewCalendar->item(agendaitem));
     }
 
-    KCalendarCore::Incidence::Ptr dayitem = d->mAllDayAgenda->selectedIncidence();
+    KCalendarCore::Incidence::Ptr const dayitem = d->mAllDayAgenda->selectedIncidence();
     if (dayitem) {
         selected.append(d->mViewCalendar->item(dayitem));
     }
@@ -1616,14 +1605,14 @@ KCalendarCore::DateList AgendaView::selectedIncidenceDates() const
 bool AgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const
 {
     if (selectionStart().isValid()) {
-        QDateTime start = selectionStart();
+        QDateTime const start = selectionStart();
         QDateTime end = selectionEnd();
 
         if (start.secsTo(end) == 15 * 60) {
             // One cell in the agenda view selected, e.g.
             // because of a double-click, => Use the default duration
-            QTime defaultDuration(CalendarSupport::KCalPrefs::instance()->defaultDuration().time());
-            int addSecs = (defaultDuration.hour() * 3600) + (defaultDuration.minute() * 60);
+            QTime const defaultDuration(CalendarSupport::KCalPrefs::instance()->defaultDuration().time());
+            int const addSecs = (defaultDuration.hour() * 3600) + (defaultDuration.minute() * 60);
             end = start.addSecs(addSecs);
         }
 
@@ -1636,7 +1625,7 @@ bool AgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &a
     // When creating an event from the side-pane view, we have no selection in the agenda
     // view, so make sure the event has the default duration as well
     if (startDt == endDt) {
-        QTime defaultDuration(CalendarSupport::KCalPrefs::instance()->defaultDuration().time());
+        QTime const defaultDuration(CalendarSupport::KCalPrefs::instance()->defaultDuration().time());
         endDt = endDt.addDuration(std::chrono::hours(defaultDuration.hour()) + std::chrono::minutes(defaultDuration.minute()));
         return true;
     }
@@ -1652,10 +1641,10 @@ bool AgendaView::selectedIsSingleCell() const
     }
 
     if (selectedIsAllDay()) {
-        int days = selectionStart().daysTo(selectionEnd());
+        int const days = selectionStart().daysTo(selectionEnd());
         return days < 1;
     } else {
-        int secs = selectionStart().secsTo(selectionEnd());
+        int const secs = selectionStart().secsTo(selectionEnd());
         return secs <= 24 * 60 * 60 / d->mAgenda->rows();
     }
 }
@@ -1721,10 +1710,10 @@ void AgendaView::updateTimeBarWidth()
     const QFont oldFont(font());
     QFont labelFont = d->mTimeLabelsZone->preferences()->agendaTimeLabelsFont();
     labelFont.setPointSize(labelFont.pointSize() - SHRINKDOWN);
-    QFontMetrics fm(labelFont);
+    QFontMetrics const fm(labelFont);
 
     int width = d->mTimeLabelsZone->preferedTimeLabelsWidth();
-    for (QLabel *l : std::as_const(d->mTimeBarHeaders)) {
+    for (const QLabel *l : std::as_const(d->mTimeBarHeaders)) {
         const auto lst = l->text().split(QLatin1Char(' '));
         for (const QString &word : lst) {
             width = qMax(width, fm.boundingRect(word).width());
@@ -1746,10 +1735,10 @@ void AgendaView::updateTimeBarWidth()
     d->mBottomDayLabelsFrame->setWeekWidth(timeBarWidth);
 }
 
-// By deafult QDateTime::toTimeSpec() will turn Qt::TimeZone to Qt::LocalTime,
+// By default QDateTime::toTimeSpec() will turn Qt::TimeZone to Qt::LocalTime,
 // which would turn the event's timezone into "floating". This code actually
 // preserves the timezone, if the spec is Qt::TimeZone.
-static QDateTime copyTimeSpec(QDateTime dt, const QDateTime &source)
+static QDateTime copyTimeSpec(const QDateTime &dt, const QDateTime &source)
 {
     switch (source.timeSpec()) {
     case Qt::TimeZone:
@@ -1794,7 +1783,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
 
     int daysLength = 0;
 
-    KCalendarCore::Incidence::Ptr incidence = item->incidence();
+    KCalendarCore::Incidence::Ptr const incidence = item->incidence();
     Akonadi::Item aitem = d->mViewCalendar->item(incidence);
     if ((!aitem.isValid() && !addIncidence) || !incidence || !changer()) {
         qCWarning(CALENDARVIEW_LOG) << "changer is " << changer() << " and incidence is " << incidence.data();
@@ -1890,7 +1879,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
         auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), collectionId);
         result = changer()->createIncidence(incidence, collection, this) != -1;
     } else {
-        KCalendarCore::Incidence::Ptr oldIncidence(Akonadi::CalendarUtils::incidence(aitem));
+        KCalendarCore::Incidence::Ptr const oldIncidence(Akonadi::CalendarUtils::incidence(aitem));
         aitem.setPayload<KCalendarCore::Incidence::Ptr>(incidence);
         result = changer()->modifyIncidence(aitem, oldIncidence, this) != -1;
     }
@@ -1979,7 +1968,7 @@ void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDa
         end = qMax(start, Akonadi::CalendarUtils::incidence(aitem)->dateTime(KCalendarCore::Incidence::RoleEnd).toLocalTime());
     }
 
-    end.toTimeZone(start.timeZone()); // allow direct comparison of dates
+    end = end.toTimeZone(start.timeZone()); // allow direct comparison of dates
     if (start.date().daysTo(end.date()) + 1 <= currentDateCount()) {
         showDates(start.date(), end.date());
     } else {
@@ -2064,25 +2053,29 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
         return false;
     }
 
+    const auto cal = calendar2(incidence);
+    if (!cal) {
+        return false;
+    }
+
     if (incidence->hasRecurrenceId()) {
         // Normally a disassociated instance belongs to a recurring instance that
         // displays it.
-        const auto cal = calendar2(incidence);
-        if (cal && cal->incidence(incidence->uid())) {
+        if (cal->incidence(incidence->uid())) {
             return false;
         }
     }
 
-    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(incidence);
+    KCalendarCore::Todo::Ptr const todo = CalendarSupport::todo(incidence);
     if (todo && (!preferences()->showTodosAgendaView() || !todo->hasDueDate())) {
         return false;
     }
 
-    KCalendarCore::Event::Ptr event = CalendarSupport::event(incidence);
+    KCalendarCore::Event::Ptr const event = CalendarSupport::event(incidence);
     const QDate today = QDate::currentDate();
 
-    QDateTime firstVisibleDateTime(d->mSelectedDates.first(), QTime(0, 0, 0), QTimeZone::LocalTime);
-    QDateTime lastVisibleDateTime(d->mSelectedDates.last(), QTime(23, 59, 59, 999), QTimeZone::LocalTime);
+    QDateTime const firstVisibleDateTime(d->mSelectedDates.first(), QTime(0, 0, 0), QTimeZone::LocalTime);
+    QDateTime const lastVisibleDateTime(d->mSelectedDates.last(), QTime(23, 59, 59, 999), QTimeZone::LocalTime);
 
     // Optimization, very cheap operation that discards incidences that aren't in the timespan
     if (!d->mightBeVisible(incidence)) {
@@ -2104,28 +2097,28 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
         const int eventDuration = event ? incDtStart.daysTo(incDtEnd.addSecs(secsToAdd)) : 0;
 
         // if there's a multiday event that starts before firstVisibleDateTime but ends after
-        // lets include it. timesInInterval() ignores incidences that aren't totaly inside
+        // let's include it. timesInInterval() ignores incidences that aren't totally inside
         // the range
         const QDateTime startDateTimeWithOffset = firstVisibleDateTime.addDays(-eventDuration);
 
-        KCalendarCore::OccurrenceIterator rIt(*calendar2(incidence), incidence, startDateTimeWithOffset, lastVisibleDateTime);
+        KCalendarCore::OccurrenceIterator rIt(*cal, incidence, startDateTimeWithOffset, lastVisibleDateTime);
         while (rIt.hasNext()) {
             rIt.next();
-            auto occurrenceDate = rIt.occurrenceStartDate().toLocalTime();
-            if (const auto todo = CalendarSupport::todo(rIt.incidence())) {
+            auto nextOccurrenceDate = rIt.occurrenceStartDate().toLocalTime();
+            if (const auto nextTodo = CalendarSupport::todo(rIt.incidence())) {
                 // Recurrence exceptions may have durations different from the normal recurrences.
-                occurrenceDate = occurrenceDate.addSecs(todo->dtStart().secsTo(todo->dtDue()));
+                nextOccurrenceDate = nextOccurrenceDate.addSecs(nextTodo->dtStart().secsTo(nextTodo->dtDue()));
             }
             const bool makesDayBusy = preferences()->colorAgendaBusyDays() && makesWholeDayBusy(rIt.incidence());
             if (makesDayBusy) {
-                KCalendarCore::Event::List &busyEvents = d->mBusyDays[occurrenceDate.date()];
+                KCalendarCore::Event::List &busyEvents = d->mBusyDays[nextOccurrenceDate.date()];
                 busyEvents.append(event);
             }
 
-            if (occurrenceDate.date() == today) {
+            if (nextOccurrenceDate.date() == today) {
                 alreadyAddedToday = true;
             }
-            d->insertIncidence(rIt.incidence(), rIt.recurrenceId(), occurrenceDate, createSelected);
+            d->insertIncidence(rIt.incidence(), rIt.recurrenceId(), nextOccurrenceDate, createSelected);
         }
     } else {
         QDateTime dateToAdd; // date to add to our date list
@@ -2206,9 +2199,9 @@ void AgendaView::updateEventIndicatorBottom(int newY)
     d->mEventIndicatorBottom->update();
 }
 
-void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &gpos, bool allDay)
+void AgendaView::slotUrlsDropped(const QList<QUrl> &urls, const QPoint &gpos, bool allDay)
 {
-    Q_UNUSED(items)
+    Q_UNUSED(urls)
     Q_UNUSED(gpos)
     Q_UNUSED(allDay)
 
@@ -2253,7 +2246,7 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
 #endif
 }
 
-static void setDateTime(KCalendarCore::Incidence::Ptr incidence, const QDateTime &dt, bool allDay)
+static void setDateTime(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &dt, bool allDay)
 {
     incidence->setAllDay(allDay);
 
@@ -2290,13 +2283,11 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
 
     const QDate day = d->mSelectedDates[gpos.x()];
     const QTime time = d->mAgenda->gyToTime(gpos.y());
-    QDateTime newTime(day, time, QTimeZone::LocalTime);
+    QDateTime const newTime(day, time, QTimeZone::LocalTime);
 
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         const Akonadi::Item existingItem = d->mViewCalendar->item(incidence);
-        const bool existsInSameCollection = existingItem.isValid();
-
-        if (existingItem.isValid() && existsInSameCollection) {
+        if (existingItem.isValid()) {
             auto newIncidence = existingItem.payload<KCalendarCore::Incidence::Ptr>();
 
             if (newIncidence->dtStart() == newTime && newIncidence->allDay() == allDay) {
@@ -2304,7 +2295,7 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
                 continue;
             }
 
-            KCalendarCore::Incidence::Ptr oldIncidence(newIncidence->clone());
+            KCalendarCore::Incidence::Ptr const oldIncidence(newIncidence->clone());
             setDateTime(newIncidence, newTime, allDay);
 
             (void)changer()->modifyIncidence(existingItem, oldIncidence, this);
@@ -2342,7 +2333,7 @@ void AgendaView::startDrag(const Akonadi::Item &incidence)
 
 void AgendaView::readSettings()
 {
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KSharedConfig::Ptr const config = KSharedConfig::openConfig();
     readSettings(config.data());
 }
 
@@ -2364,7 +2355,7 @@ void AgendaView::writeSettings(KConfig *config)
 {
     KConfigGroup group = config->group(QStringLiteral("Views"));
 
-    QList<int> list = d->mSplitterAgenda->sizes();
+    QList<int> const list = d->mSplitterAgenda->sizes();
     group.writeEntry("Separator AgendaView", list);
 }
 
@@ -2399,7 +2390,7 @@ void AgendaView::setHolidayMasks()
 
     // Store the information about the day before the visible area (needed for
     // overnight working hours) in the last bit of the mask:
-    bool showDay = !workDays.contains(d->mSelectedDates[0].addDays(-1));
+    bool const showDay = !workDays.contains(d->mSelectedDates[0].addDays(-1));
     d->mHolidayMask[d->mSelectedDates.count()] = showDay;
 
     d->mAgenda->setHolidayMask(&d->mHolidayMask);
