@@ -28,24 +28,17 @@ MonthScene::MonthScene(MonthView *parent)
     : QGraphicsScene(parent)
     , mMonthView(parent)
     , mInitialized(false)
-    , mClickedItem(nullptr)
-    , mActionItem(nullptr)
     , mActionInitiated(false)
-    , mSelectedItem(nullptr)
-    , mStartCell(nullptr)
-    , mPreviousCell(nullptr)
     , mActionType(None)
     , mStartHeight(0)
-    , mCurrentIndicator(nullptr)
+    , mBirthdayPixmap(QIcon::fromTheme(QStringLiteral("view-calendar-birthday")).pixmap(16, 16))
+    , mAnniversaryPixmap(QIcon::fromTheme(QStringLiteral("view-calendar-wedding-anniversary")).pixmap(16, 16))
+    , mAlarmPixmap(QIcon::fromTheme(QStringLiteral("appointment-reminder")).pixmap(16, 16))
+    , mRecurPixmap(QIcon::fromTheme(QStringLiteral("appointment-recurring")).pixmap(16, 16))
+    , mReadonlyPixmap(QIcon::fromTheme(QStringLiteral("object-locked")).pixmap(16, 16))
+    , mReplyPixmap(QIcon::fromTheme(QStringLiteral("mail-reply-sender")).pixmap(16, 16))
+    , mHolidayPixmap(QIcon::fromTheme(QStringLiteral("view-calendar-holiday")).pixmap(16, 16))
 {
-    mBirthdayPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-birthday")).pixmap(16, 16);
-    mAnniversaryPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-wedding-anniversary")).pixmap(16, 16);
-    mAlarmPixmap = QIcon::fromTheme(QStringLiteral("appointment-reminder")).pixmap(16, 16);
-    mRecurPixmap = QIcon::fromTheme(QStringLiteral("appointment-recurring")).pixmap(16, 16);
-    mReadonlyPixmap = QIcon::fromTheme(QStringLiteral("object-locked")).pixmap(16, 16);
-    mReplyPixmap = QIcon::fromTheme(QStringLiteral("mail-reply-sender")).pixmap(16, 16);
-    mHolidayPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-holiday")).pixmap(16, 16);
-
     setSceneRect(0, 0, parent->width(), parent->height());
 }
 
@@ -67,7 +60,7 @@ MonthCell *MonthScene::previousCell() const
 
 int MonthScene::getRightSpan(QDate date) const
 {
-    MonthCell *cell = mMonthCellMap.value(date);
+    const MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
         return 0;
     }
@@ -77,7 +70,7 @@ int MonthScene::getRightSpan(QDate date) const
 
 int MonthScene::getLeftSpan(QDate date) const
 {
-    MonthCell *cell = mMonthCellMap.value(date);
+    const MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
         return 0;
     }
@@ -168,7 +161,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
 {
     Q_ASSERT(mScene);
 
-    PrefsPtr prefs = mScene->monthView()->preferences();
+    PrefsPtr const prefs = mScene->monthView()->preferences();
     p->setFont(prefs->monthViewFont());
     p->fillRect(rect, palette().color(QPalette::Window));
 
@@ -186,7 +179,10 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
                       static_cast<int>(mScene->sceneRect().width()),
                       static_cast<int>(mScene->headerHeight() - dayLabelsHeight)),
                 Qt::AlignCenter,
-                i18nc("monthname year", "%1 %2", QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat), QString::number(dayInMonth.year())));
+                i18nc("monthname year",
+                      "%1 %2",
+                      QLocale().standaloneMonthName(dayInMonth.month(), QLocale::LongFormat),
+                      QString::number(dayInMonth.year()))); // krazy:exclude=i18ncheckargs
 
     font.setPointSize(dayLabelsHeight - 10);
     p->setFont(font);
@@ -211,9 +207,9 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     /*
       Month grid
     */
-    int columnWidth = mScene->columnWidth();
-    int rowHeight = mScene->rowHeight();
-    QDate todayDate{QDate::currentDate()};
+    int const columnWidth = mScene->columnWidth();
+    int const rowHeight = mScene->rowHeight();
+    QDate const todayDate{QDate::currentDate()};
 
     const QList<QDate> workDays = CalendarSupport::workDays(mMonthView->actualStartDateTime().date(), mMonthView->actualEndDateTime().date());
     QRect todayRect;
@@ -257,7 +253,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
         }
     }
     if (!todayRect.isNull()) {
-        KColorScheme scheme(QPalette::Normal, KColorScheme::ColorSet::View);
+        KColorScheme const scheme(QPalette::Normal, KColorScheme::ColorSet::View);
         p->setPen(scheme.foreground(KColorScheme::ForegroundRole::PositiveText).color());
         p->setBrush(scheme.background(KColorScheme::BackgroundRole::PositiveBackground));
         p->drawRect(todayRect);
@@ -290,18 +286,18 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
         MonthCell *const cell = mScene->mMonthCellMap.value(d);
 
         // Draw cell header
-        int cellHeaderX = mScene->cellHorizontalPos(cell) + 1;
-        int cellHeaderY = mScene->cellVerticalPos(cell) + 1;
-        int cellHeaderWidth = columnWidth - 2;
-        int cellHeaderHeight = cell->topMargin() - 2;
+        int const cellHeaderX = mScene->cellHorizontalPos(cell) + 1;
+        int const cellHeaderY = mScene->cellVerticalPos(cell) + 1;
+        int const cellHeaderWidth = columnWidth - 2;
+        int const cellHeaderHeight = cell->topMargin() - 2;
         const auto brush = KColorScheme(QPalette::Normal, KColorScheme::ColorSet::Header).background(KColorScheme::BackgroundRole::NormalBackground);
         p->setBrush(brush);
         p->setPen(Qt::NoPen);
         p->drawRect(QRect(cellHeaderX, cellHeaderY, cellHeaderWidth, cellHeaderHeight));
 
-        QFont font = p->font();
-        font.setBold(cell->date() == todayDate);
-        p->setFont(font);
+        QFont boldFont = p->font();
+        boldFont.setBold(cell->date() == todayDate);
+        p->setFont(boldFont);
 
         if (d.month() == mMonthView->currentMonth()) {
             p->setPen(palette().color(QPalette::WindowText));
@@ -330,8 +326,10 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
 
         // Up arrow if first item is above cell top
         if (mScene->startHeight() != 0 && cell->hasEventBelow(mScene->startHeight())) {
+            // NOLINTBEGIN(bugprone-integer-division)
             cell->upArrow()->setPos(mScene->cellHorizontalPos(cell) + columnWidth / 2,
                                     mScene->cellVerticalPos(cell) + cell->upArrow()->boundingRect().height() / 2 + 2);
+            // NOLINTEND(bugprone-integer-division)
             cell->upArrow()->show();
         } else {
             cell->upArrow()->hide();
@@ -339,8 +337,10 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
 
         // Down arrow if last item is below cell bottom
         if (!mScene->lastItemFit(cell)) {
+            // NOLINTBEGIN(bugprone-integer-division)
             cell->downArrow()->setPos(mScene->cellHorizontalPos(cell) + columnWidth / 2,
                                       mScene->cellVerticalPos(cell) + rowHeight - cell->downArrow()->boundingRect().height() / 2 - 2);
+            // NOLINTEND(bugprone-integer-division)
             cell->downArrow()->show();
         } else {
             cell->downArrow()->hide();
@@ -384,7 +384,7 @@ int MonthScene::totalHeight()
 {
     int max = 0;
     for (QDate d = mMonthView->actualStartDateTime().date(); d <= mMonthView->actualEndDateTime().date(); d = d.addDays(1)) {
-        int c = mMonthCellMap[d]->firstFreeSpace();
+        int const c = mMonthCellMap[d]->firstFreeSpace();
         if (c > max) {
             max = c;
         }
@@ -441,7 +441,7 @@ void MonthScene::wheelEvent(QGraphicsSceneWheelEvent *event)
 
 void MonthScene::scrollCellsDown()
 {
-    int newHeight = startHeight() + 1;
+    int const newHeight = startHeight() + 1;
     setStartHeight(newHeight);
 
     for (MonthItem *manager : std::as_const(mManagerList)) {
@@ -453,7 +453,7 @@ void MonthScene::scrollCellsDown()
 
 void MonthScene::scrollCellsUp()
 {
-    int newHeight = startHeight() - 1;
+    int const newHeight = startHeight() - 1;
     setStartHeight(newHeight);
 
     for (MonthItem *manager : std::as_const(mManagerList)) {
@@ -474,9 +474,9 @@ void MonthScene::clickOnScrollIndicator(ScrollIndicator *scrollItem)
 
 void MonthScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
-    QPointF pos = mouseEvent->scenePos();
+    QPointF const pos = mouseEvent->scenePos();
     repeatTimer.stop();
-    MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
+    const MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
     if (iItem) {
         if (iItem->monthItem()) {
             auto tmp = qobject_cast<IncidenceMonthItem *>(iItem->monthItem());
@@ -488,7 +488,7 @@ void MonthScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
             }
         }
     } else {
-        QDate currentDate = getCellFromPos(pos)->date();
+        QDate const currentDate = getCellFromPos(pos)->date();
         if (currentDate.isValid()) {
             Q_EMIT newEventSignal(currentDate);
         } else {
@@ -499,7 +499,7 @@ void MonthScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
 void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
-    QPointF pos = mouseEvent->scenePos();
+    QPointF const pos = mouseEvent->scenePos();
 
     MonthGraphicsView *view = static_cast<MonthGraphicsView *>(views().at(0));
 
@@ -508,6 +508,7 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
     if (mActionType == None) {
         MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
         if (iItem) {
+            // NOLINTBEGIN(bugprone-branch-clone)
             if (iItem->monthItem()->isResizable() && iItem->isBeginItem() && iItem->mapFromScene(pos).x() <= 10) {
                 view->setActionCursor(Resize);
             } else if (iItem->monthItem()->isResizable() && iItem->isEndItem() && iItem->mapFromScene(pos).x() >= iItem->boundingRect().width() - 10) {
@@ -515,6 +516,7 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
             } else {
                 view->setActionCursor(None);
             }
+            // NOLINTEND(bugprone-branch-clone)
         } else {
             view->setActionCursor(None);
         }
@@ -540,17 +542,8 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
         if (currentCell && currentCell != mPreviousCell) {
             bool ok = true;
             if (mActionType == Move) {
-                if (currentCell) {
-                    mActionItem->moveTo(currentCell->date());
-                    mActionItem->updateGeometry();
-                } else {
-                    mActionItem->moveTo(QDate());
-                    mActionItem->updateGeometry();
-                    mActionItem->endMove();
-                    mActionItem = nullptr;
-                    mActionType = None;
-                    mStartCell = nullptr;
-                }
+                mActionItem->moveTo(currentCell->date());
+                mActionItem->updateGeometry();
             } else if (mActionType == Resize) {
                 ok = mActionItem->resizeBy(mPreviousCell->date().daysTo(currentCell->date()));
                 mActionItem->updateGeometry();
@@ -567,7 +560,7 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
 void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
-    QPointF pos = mouseEvent->scenePos();
+    QPointF const pos = mouseEvent->scenePos();
 
     mClickedItem = nullptr;
     mCurrentIndicator = nullptr;
@@ -611,7 +604,7 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
         // unselect items when clicking somewhere else
         selectItem(nullptr);
 
-        MonthCell *cell = getCellFromPos(pos);
+        const MonthCell *cell = getCellFromPos(pos);
         if (cell) {
             mSelectedCellDate = cell->date();
             update();
@@ -640,7 +633,7 @@ void MonthScene::helpEvent(QGraphicsSceneHelpEvent *helpEvent)
 {
     // Find the first item that does tooltips
     const QPointF pos = helpEvent->scenePos();
-    MonthGraphicsItem *toolTipItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
+    const MonthGraphicsItem *toolTipItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
 
     // Show or hide the tooltip
     QString text;
@@ -655,7 +648,7 @@ void MonthScene::helpEvent(QGraphicsSceneHelpEvent *helpEvent)
 
 void MonthScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
-    QPointF pos = mouseEvent->scenePos();
+    QPointF const pos = mouseEvent->scenePos();
 
     static_cast<MonthGraphicsView *>(views().at(0))->setActionCursor(None);
 
@@ -663,7 +656,7 @@ void MonthScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
     mCurrentIndicator = nullptr;
 
     if (mActionItem) {
-        MonthCell *currentCell = getCellFromPos(pos);
+        const MonthCell *currentCell = getCellFromPos(pos);
 
         const bool somethingChanged = currentCell && currentCell != mStartCell;
 
@@ -694,12 +687,12 @@ bool MonthScene::isInMonthGrid(int x, int y) const
 // be able to locate the cell.
 MonthCell *MonthScene::getCellFromPos(QPointF pos)
 {
-    int y = sceneYToMonthGridY(static_cast<int>(pos.y()));
-    int x = sceneXToMonthGridX(static_cast<int>(pos.x()));
+    int const y = sceneYToMonthGridY(static_cast<int>(pos.y()));
+    int const x = sceneXToMonthGridX(static_cast<int>(pos.x()));
     if (!isInMonthGrid(x, y)) {
         return nullptr;
     }
-    int id = (int)(y / rowHeight()) * 7 + (int)(x / columnWidth());
+    int const id = (int)(y / rowHeight()) * 7 + (int)(x / columnWidth());
 
     return mMonthCellMap.value(mMonthView->actualStartDateTime().date().addDays(id));
 }
@@ -743,7 +736,7 @@ void MonthScene::removeIncidence(const QString &uid)
             continue;
         }
 
-        KCalendarCore::Incidence::Ptr incidence = imi->incidence();
+        KCalendarCore::Incidence::Ptr const incidence = imi->incidence();
         if (!incidence) {
             continue;
         }
