@@ -48,11 +48,11 @@ public: /// Methods
     // void setUpModels();
     void triggerDelayedReload(EventView::Change reason);
 
-public: /// Members
+    /// Members
     QTimer reloadTimer;
     MonthScene *scene = nullptr;
     QDate selectedItemDate;
-    Akonadi::Item::Id selectedItemId;
+    Akonadi::Item::Id selectedItemId{-1};
     MonthGraphicsView *view = nullptr;
     QToolButton *fullView = nullptr;
 
@@ -74,9 +74,8 @@ private:
 MonthViewPrivate::MonthViewPrivate(MonthView *qq)
     : q(qq)
     , scene(new MonthScene(qq))
-    , selectedItemId(-1)
     , view(new MonthGraphicsView(qq))
-    , fullView(nullptr)
+
 {
     reloadTimer.setSingleShot(true);
     view->setScene(scene);
@@ -310,7 +309,7 @@ KCalendarCore::DateList MonthView::selectedIncidenceDates() const
     if (d->scene->selectedItem()) {
         auto tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
         if (tmp) {
-            QDate selectedItemDate = tmp->realStartDate();
+            QDate const selectedItemDate = tmp->realStartDate();
             if (selectedItemDate.isValid()) {
                 list << selectedItemDate;
             }
@@ -469,7 +468,7 @@ void MonthView::keyReleaseEvent(QKeyEvent *event)
 
 void MonthView::changeFullView()
 {
-    bool fullView = d->fullView->isChecked();
+    bool const fullView = d->fullView->isChecked();
 
     if (fullView) {
         d->fullView->setIcon(QIcon::fromTheme(QStringLiteral("view-restore")));
@@ -531,7 +530,7 @@ Akonadi::Item::List MonthView::selectedIncidences() const
     if (d->scene->selectedItem()) {
         auto tmp = qobject_cast<IncidenceMonthItem *>(d->scene->selectedItem());
         if (tmp) {
-            Akonadi::Item incidenceSelected = tmp->akonadiItem();
+            Akonadi::Item const incidenceSelected = tmp->akonadiItem();
             if (incidenceSelected.isValid()) {
                 selected.append(incidenceSelected);
             }
@@ -545,7 +544,7 @@ KHolidays::Holiday::List MonthView::holidays(QDate startDate, QDate endDate)
     KHolidays::Holiday::List holidays;
     auto const regions = CalendarSupport::KCalPrefs::instance()->mHolidays;
     for (auto const &r : regions) {
-        KHolidays::HolidayRegion region(r);
+        KHolidays::HolidayRegion const region(r);
         if (region.isValid()) {
             holidays += region.rawHolidaysWithAstroSeasons(startDate, endDate);
         }
@@ -559,7 +558,7 @@ void MonthView::reloadIncidences()
         return;
     }
     // keep selection if it exists
-    Akonadi::Item incidenceSelected;
+    Akonadi::Item const incidenceSelected;
 
     MonthItem *itemToReselect = nullptr;
 
@@ -581,7 +580,8 @@ void MonthView::reloadIncidences()
     }
 
     // build global event list
-    for (const auto &calendar : calendars()) {
+    const auto cals = calendars();
+    for (const auto &calendar : cals) {
         auto *newItemToReselect = d->loadCalendarIncidences(calendar, actualStartDateTime(), actualEndDateTime());
         if (itemToReselect == nullptr) {
             itemToReselect = newItemToReselect;
@@ -593,8 +593,10 @@ void MonthView::reloadIncidences()
     }
 
     // add holidays
-    for (auto const &h : holidays(actualStartDateTime().date(), actualEndDateTime().date())) {
+    auto const hols = holidays(actualStartDateTime().date(), actualEndDateTime().date());
+    for (auto const &h : hols) {
         if (h.dayType() == KHolidays::Holiday::NonWorkday) {
+            /* cppcheck-suppress constVariablePointer */
             MonthItem *holidayItem = new HolidayMonthItem(d->scene, h.observedStartDate(), h.observedEndDate(), h.name());
             d->scene->mManagerList << holidayItem;
         }
@@ -604,6 +606,7 @@ void MonthView::reloadIncidences()
     std::sort(d->scene->mManagerList.begin(), d->scene->mManagerList.end(), MonthItem::greaterThan);
 
     // build each month's cell event list
+    /* cppcheck-suppress constVariablePointer */
     for (MonthItem *manager : std::as_const(d->scene->mManagerList)) {
         for (QDate date = manager->startDate(); date <= manager->endDate(); date = date.addDays(1)) {
             MonthCell *cell = d->scene->mMonthCellMap.value(date);
