@@ -88,12 +88,18 @@ public:
 
     void addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+        beginFilterChange();
+#endif
         mEnabledCalendars.insert(calendar->collection().id());
         invalidateFilter();
     }
 
     void removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+        beginFilterChange();
+#endif
         mEnabledCalendars.remove(calendar->collection().id());
         invalidateFilter();
     }
@@ -124,6 +130,7 @@ public:
         delete todoFlatModel;
     }
 
+    /* cppcheck-suppress constParameterPointer */
     void registerView(TodoView *view)
     {
         views << view;
@@ -206,6 +213,11 @@ public:
     Akonadi::IncidenceTreeModel *todoTreeModel = nullptr;
     Akonadi::EntityMimeTypeFilterModel *todoFlatModel = nullptr;
     EventViews::PrefsPtr prefs;
+
+private:
+    // disable copy ctor
+    ModelStack(const ModelStack &) = delete;
+    ModelStack &operator=(const ModelStack &) = delete;
 };
 }
 
@@ -215,8 +227,6 @@ static ModelStack *sModels = nullptr;
 TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget *parent)
     : EventView(parent)
     , mCalendarFilterModel(std::make_unique<CalendarFilterModel>())
-    , mQuickSearch(nullptr)
-    , mQuickAdd(nullptr)
     , mTreeStateRestorer(nullptr)
     , mSidebarView(sidebarView)
     , mResizeColumnsScheduled(false)
@@ -231,7 +241,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
         sModels = new ModelStack(prefs, parent);
         connect(sModels->todoModel, &Akonadi::TodoModel::dropOnSelfRejected, this, []() {
             KMessageBox::information(nullptr,
-                                     i18n("Cannot move to-do to itself or a child of itself."),
+                                     i18nc("@info", "Cannot move to-do to itself or a child of itself."),
                                      i18nc("@title:window", "Drop To-do"),
                                      QStringLiteral("NoDropTodoOntoItself"));
         });
@@ -303,7 +313,12 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mQuickAdd = new TodoViewQuickAddLine(this);
     mQuickAdd->setClearButtonEnabled(true);
     mQuickAdd->setVisible(preferences()->enableQuickTodo());
-    connect(mQuickAdd, &TodoViewQuickAddLine::returnPressed, this, &TodoView::addQuickTodo);
+    mQuickAdd->setToolTip(i18nc("@info:tooltip", "Create an open-ended to-do"));
+    mQuickAdd->setWhatsThis(
+        xi18nc("@info:whatsthis",
+               "Enter the summary for a new to-do. <para><note>The new to-do will be open-ended meaning that it has no start or end times nor "
+               "will it have a reminder or recurrence. Edit the newly created if you want to add more properties.</note></para>"));
+    connect(mQuickAdd, &TodoViewQuickAddLine::returnPressedSignal, this, &TodoView::addQuickTodo);
 
     mFullViewButton = nullptr;
     if (!mSidebarView) {
@@ -311,17 +326,19 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
         mFullViewButton->setAutoRaise(true);
         mFullViewButton->setCheckable(true);
 
-        mFullViewButton->setToolTip(i18nc("@info:tooltip", "Display to-do list in a full window"));
-        mFullViewButton->setWhatsThis(i18nc("@info:whatsthis", "Checking this option will cause the to-do view to use the full window."));
+        mFullViewButton->setToolTip(i18nc("@info:tooltip", "Display to-dos in a full window without the sidebar"));
+        mFullViewButton->setWhatsThis(i18nc("@info:whatsthis",
+                                            "Checking this button will cause the to-dos to be displayed in a larger window "
+                                            "by hiding the sidebar."));
     }
     mFlatViewButton = new QToolButton(this);
     mFlatViewButton->setAutoRaise(true);
     mFlatViewButton->setCheckable(true);
-    mFlatViewButton->setToolTip(i18nc("@info:tooltip", "Display to-dos in flat list instead of a tree"));
+    mFlatViewButton->setToolTip(i18nc("@info:tooltip", "Display to-dos in a flat list or a tree"));
     mFlatViewButton->setWhatsThis(i18nc("@info:whatsthis",
-                                        "Checking this option will cause the to-dos to be displayed as a "
-                                        "flat list instead of a hierarchical tree; the parental "
-                                        "relationships are removed in the display."));
+                                        "Checking this button will cause the to-dos to be displayed either as a "
+                                        "flat list or a hierarchical tree where the parental "
+                                        "relationships are removed."));
 
     connect(mFlatViewButton, &QToolButton::toggled, this, [this](bool flatView) {
         setFlatView(flatView, true);
@@ -419,6 +436,15 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
+    mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("task-complete")),
+                              i18nc("@action:inmenu set or unset to-do is completed", "Togg&le To-do Completed"),
+                              this,
+                              &TodoView::toggleTodoCompleted);
+    mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("task-reminder")),
+                              i18nc("@action:inmenu enable or disable reminder", "&Toggle Reminder"),
+                              this,
+                              &TodoView::toggleTodoAlarm);
+
     mItemPopupMenu->addSeparator();
 
     mCopyPopupMenu = new KDatePickerPopup(KDatePickerPopup::NoDate | KDatePickerPopup::DatePicker | KDatePickerPopup::Words, QDate::currentDate(), this);
@@ -484,7 +510,7 @@ TodoView::~TodoView()
 
 void TodoView::expandIndex(const QModelIndex &index)
 {
-    QModelIndex todoModelIndex = sModels->todoModel->mapFromSource(index);
+    const QModelIndex todoModelIndex = sModels->todoModel->mapFromSource(index);
     Q_ASSERT(todoModelIndex.isValid());
     const auto coloredIndex = sModels->coloredTodoModel->mapFromSource(todoModelIndex);
     Q_ASSERT(coloredIndex.isValid());
@@ -578,7 +604,7 @@ void TodoView::saveLayout(KConfig *config, const QString &group) const
 
 void TodoView::restoreLayout(KConfig *config, const QString &group, bool minimalDefaults)
 {
-    KConfigGroup cfgGroup = config->group(group);
+    const KConfigGroup cfgGroup = config->group(group);
     QHeaderView *header = mView->header();
 
     QVariantList columnVisibility = cfgGroup.readEntry("ColumnVisibility", QVariantList());
@@ -603,9 +629,9 @@ void TodoView::restoreLayout(KConfig *config, const QString &group, bool minimal
         QTimer::singleShot(0, this, &TodoView::resizeColumns);
     } else {
         for (int i = 0; i < header->count() && i < columnOrder.size() && i < columnWidths.size() && i < columnVisibility.size(); i++) {
-            bool visible = columnVisibility[i].toBool();
-            int width = columnWidths[i].toInt();
-            int order = columnOrder[i].toInt();
+            const bool visible = columnVisibility[i].toBool();
+            const int width = columnWidths[i].toInt();
+            const int order = columnOrder[i].toInt();
 
             header->resizeSection(i, width);
             header->moveSection(header->visualIndex(i), order);
@@ -615,8 +641,8 @@ void TodoView::restoreLayout(KConfig *config, const QString &group, bool minimal
         }
     }
 
-    int sortOrder = cfgGroup.readEntry("SortAscending", (int)Qt::AscendingOrder);
-    int sortColumn = cfgGroup.readEntry("SortColumn", -1);
+    const int sortOrder = cfgGroup.readEntry("SortAscending", (int)Qt::AscendingOrder);
+    const int sortColumn = cfgGroup.readEntry("SortColumn", -1);
     if (sortColumn >= 0) {
         mView->sortByColumn(sortColumn, (Qt::SortOrder)sortOrder);
     }
@@ -648,11 +674,12 @@ void TodoView::showIncidences(const Akonadi::Item::List &incidenceList, const QD
 
 void TodoView::updateView()
 {
-    if (calendars().empty()) {
+    auto calendarList = calendars();
+    if (calendarList.isEmpty()) {
         return;
     }
 
-    auto calendar = calendars().first();
+    auto &calendar = calendarList.first();
     mProxyModel->setCalFilter(calendar->filter());
 }
 
@@ -691,9 +718,9 @@ void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
         return;
     }
 
-    KCalendarCore::Todo::Ptr parent = Akonadi::CalendarUtils::todo(parentItem);
+    const KCalendarCore::Todo::Ptr parent = Akonadi::CalendarUtils::todo(parentItem);
 
-    KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
+    const KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
     todo->setSummary(summaryTrimmed);
     todo->setOrganizer(Person(CalendarSupport::KCalPrefs::instance()->fullName(), CalendarSupport::KCalPrefs::instance()->email()));
 
@@ -703,11 +730,19 @@ void TodoView::addTodo(const QString &summary, const Akonadi::Item &parentItem,
         todo->setRelatedTo(parent->uid());
     }
 
-    Akonadi::Collection collection;
+    /* A todo without a start datetime can't have a reminder so don't bother adding one
+    if (CalendarSupport::KCalPrefs::instance()->defaultTodoReminders()) {
+        KCalendarCore::Alarm::Ptr alarm = todo->newAlarm();
+        CalendarSupport::createAlarmReminder(alarm, todo->type());
+    }
+    */
 
+    // TODO: use the default todo calendar id (once we have one)
+    // Akonadi::Collection collection = Akonadi::EntityTreeModel::updatedCollection(model(), CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    Akonadi::Collection collection;
     // Use the same collection of the parent.
     if (parentItem.isValid()) {
-        // Don't use parentColection() since it might be a virtual collection
+        // Don't use parentCollection() since it might be a virtual collection
         collection = Akonadi::EntityTreeModel::updatedCollection(model(), parentItem.storageCollectionId());
     }
 
@@ -749,7 +784,7 @@ void TodoView::contextMenu(QPoint pos)
             if (incidences.isEmpty()) {
                 enable = false;
             } else {
-                Akonadi::Item item = incidences.first();
+                const Akonadi::Item &item = incidences.first();
                 incidencePtr = Akonadi::CalendarUtils::incidence(item);
 
                 // Action isn't RO, it can change the incidence, "Edit" for example.
@@ -867,9 +902,24 @@ void TodoView::newSubTodo()
         const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
 
         Q_EMIT newSubTodoSignal(todoItem);
-    } else {
-        // This never happens
-        qCWarning(CALENDARVIEW_LOG) << "Selection size isn't 1";
+    }
+}
+
+void TodoView::toggleTodoCompleted()
+{
+    QModelIndexList selection = mView->selectionModel()->selectedRows();
+    if (selection.size() == 1) {
+        const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
+        Q_EMIT toggleTodoCompletedSignal(todoItem);
+    }
+}
+
+void TodoView::toggleTodoAlarm()
+{
+    QModelIndexList selection = mView->selectionModel()->selectedRows();
+    if (selection.size() == 1) {
+        const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
+        Q_EMIT toggleAlarmSignal(todoItem);
     }
 }
 
@@ -894,7 +944,7 @@ void TodoView::copyTodoToDate(QDate date)
         return;
     }
 
-    KCalendarCore::Todo::Ptr todo(orig->clone());
+    const KCalendarCore::Todo::Ptr todo(orig->clone());
 
     todo->setUid(KCalendarCore::CalFormat::createUniqueId());
 
@@ -914,7 +964,7 @@ void TodoView::scheduleResizeColumns()
 void TodoView::itemDoubleClicked(const QModelIndex &index)
 {
     if (index.isValid()) {
-        QModelIndex summary = index.sibling(index.row(), Akonadi::TodoModel::SummaryColumn);
+        const QModelIndex summary = index.sibling(index.row(), Akonadi::TodoModel::SummaryColumn);
         if (summary.flags() & Qt::ItemIsEditable) {
             editTodo();
         } else {
@@ -933,7 +983,7 @@ QMenu *TodoView::createCategoryPopupMenu()
     }
 
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     const QStringList checkedCategories = todo->categories();
@@ -979,12 +1029,12 @@ void TodoView::setNewDate(QDate date)
     }
 
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), todoItem.storageCollectionId());
     if (collection.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        const KCalendarCore::Todo::Ptr oldTodo(todo->clone());
         QDateTime dt(date.startOfDay());
 
         if (!todo->allDay()) {
@@ -1010,12 +1060,12 @@ void TodoView::setStartDate(QDate date)
     }
 
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), todoItem.storageCollectionId());
     if (collection.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        const KCalendarCore::Todo::Ptr oldTodo(todo->clone());
         QDateTime dt(date.startOfDay());
 
         if (!todo->allDay()) {
@@ -1041,14 +1091,14 @@ void TodoView::setNewPercentage(QAction *action)
     }
 
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
 
     const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), todoItem.storageCollectionId());
     if (collection.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        const KCalendarCore::Todo::Ptr oldTodo(todo->clone());
 
-        int percentage = mPercentage.value(action);
+        const int percentage = mPercentage.value(action);
         if (percentage == 100) {
             todo->setCompleted(QDateTime::currentDateTime());
             todo->setPercentComplete(100);
@@ -1068,10 +1118,10 @@ void TodoView::setNewPriority(QAction *action)
         return;
     }
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), todoItem.storageCollectionId());
     if (collection.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        const KCalendarCore::Todo::Ptr oldTodo(todo->clone());
         todo->setPriority(mPriority[action]);
 
         changer()->modifyIncidence(todoItem, oldTodo, this);
@@ -1086,11 +1136,11 @@ void TodoView::changedCategories(QAction *action)
     }
 
     const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-    KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
+    const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
     Q_ASSERT(todo);
     const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), todoItem.storageCollectionId());
     if (collection.rights() & Akonadi::Collection::CanChangeItem) {
-        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        const KCalendarCore::Todo::Ptr oldTodo(todo->clone());
 
         const QString cat = action->data().toString();
         QStringList categories = todo->categories();
@@ -1116,8 +1166,10 @@ void TodoView::setFullView(bool fullView)
     mFullViewButton->setChecked(fullView);
     if (fullView) {
         mFullViewButton->setIcon(QIcon::fromTheme(QStringLiteral("view-restore")));
+        mFullViewButton->setToolTip(i18nc("@info:tooltip", "Display the sidebar"));
     } else {
         mFullViewButton->setIcon(QIcon::fromTheme(QStringLiteral("view-fullscreen")));
+        mFullViewButton->setToolTip(i18nc("@info:tooltip", "Hide the sidebar"));
     }
 
     mFullViewButton->blockSignals(true);
@@ -1136,8 +1188,10 @@ void TodoView::setFlatView(bool flatView, bool notifyOtherViews)
 {
     if (flatView) {
         mFlatViewButton->setIcon(QIcon::fromTheme(QStringLiteral("view-list-tree")));
+        mFlatViewButton->setToolTip(i18nc("@info::tooltip", "Switch to the tree list display"));
     } else {
         mFlatViewButton->setIcon(QIcon::fromTheme(QStringLiteral("view-list-details")));
+        mFlatViewButton->setToolTip(i18nc("@info::tooltip", "Switch to the flat list display"));
     }
 
     if (notifyOtherViews) {
@@ -1151,10 +1205,10 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
         return;
     }
 
-    QModelIndex idx = mView->model()->index(start, 0);
+    const QModelIndex idx = mView->model()->index(start, 0);
 
     // If the collection is currently being populated, we don't do anything
-    QVariant v = idx.data(Akonadi::EntityTreeModel::ItemRole);
+    const QVariant v = idx.data(Akonadi::EntityTreeModel::ItemRole);
     if (!v.isValid()) {
         return;
     }
@@ -1171,11 +1225,11 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
 
     // Case #1, adding an item that doesn't have parent: We select it
     if (!parent.isValid()) {
-        QModelIndexList selection = mView->selectionModel()->selectedRows();
+        const QModelIndexList selection = mView->selectionModel()->selectedRows();
         if (selection.size() <= 1) {
             // don't destroy complex selections, not applicable now (only single
             // selection allowed), but for the future...
-            int colCount = static_cast<int>(Akonadi::TodoModel::ColumnCount);
+            const int colCount = static_cast<int>(Akonadi::TodoModel::ColumnCount);
             mView->selectionModel()->select(QItemSelection(idx, mView->model()->index(start, colCount - 1)),
                                             QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         }
@@ -1271,8 +1325,8 @@ void TodoView::restoreViewState()
     // timer.start();
     delete mTreeStateRestorer;
     mTreeStateRestorer = new Akonadi::ETMViewStateSaver();
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group(config, stateSaverGroup());
+    const KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    const KConfigGroup group(config, stateSaverGroup());
     mTreeStateRestorer->setView(mView);
     mTreeStateRestorer->restoreState(group);
     // qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed();
